pub enum DescriptorTree<Pk: MiniscriptKey> {
Keyless(bool),
Key(Pk),
Threshold(Threshold<DescriptorTree<Pk>, 0>),
}Expand description
A tree can be keyless, a key, or a threshold of trees
Variants
Keyless(bool)
A keyless tree that can be either satisfiable or unsatisfiable
Key(Pk)
A key
Threshold(Threshold<DescriptorTree<Pk>, 0>)
A threshold of trees
Implementations
Sourceimpl<Pk: MiniscriptKey> DescriptorTree<Pk>
impl<Pk: MiniscriptKey> DescriptorTree<Pk>
Sourcepub fn extract_keys(&self) -> Vec<Pk>
pub fn extract_keys(&self) -> Vec<Pk>
Returns a list of keys in the descriptor
Sourcepub fn prune_keyless(&self) -> Option<KeylessDescriptorTree<Pk>>
pub fn prune_keyless(&self) -> Option<KeylessDescriptorTree<Pk>>
Prune keyless leaves assuming satisifiable conditions are satisfied. Sets new_k = max(old_k - num(satisfiable keyless leaves), 0) in each threshold.