pub enum KeylessDescriptorTree<Pk: MiniscriptKey> {
Key(Pk),
Threshold(Threshold<KeylessDescriptorTree<Pk>, 0>),
}Expand description
A tree can a key, or a threshold of trees
Variants
Implementations
Sourceimpl<Pk: MiniscriptKey> KeylessDescriptorTree<Pk>
impl<Pk: MiniscriptKey> KeylessDescriptorTree<Pk>
Sourcepub fn extract_keys(&self) -> Vec<Pk>
pub fn extract_keys(&self) -> Vec<Pk>
Returns a list of keys in the pruned descriptor